configure

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2021 License: MIT Imports: 6 Imported by: 0

README

configure

A config manager for Go applications.

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrNotPointerToStruct is returned when the provided target is not pointer to struct.
	ErrNotPointerToStruct = errors.New("target should be pointer to struct")
)

Functions

This section is empty.

Types

type ILoader

type ILoader interface {
	// Load accepts pointer to a struct and loads the config into it.
	Load(target interface{}) error
}

ILoader abstracts a configuration loader.

func NewLoader

func NewLoader() ILoader

NewLoader creates and returns a new Loader.

Directories

Path Synopsis

Jump to